# README - brad documentation

This directory contains the documentation for Brad. It is built with
[`mkdocs`](https://www.mkdocs.org/). To get started, install the dependencies.

```
# starting from docs/ directory
pip install -U requirements-docs.txt
```

Preview the documentation site with

```
mkdocs serve
```

or build with

```
mkdocs build
```

Deployment to GitHub Pages is taken care of by GitHub Actions each time changes
are merged to `main`.
